@@ -9,7 +9,8 @@ Misc
 Wine
 </name>
 
-<description>run Windows applications without a copy of Microsoft Windows
+<description>
+run Windows applications without a copy of Microsoft Windows
 </description>
 
 <installable>
