@@ -17,7 +17,7 @@ lightweight environment
 all
 </installable>
 
-<screenshot>https://screenshots.debian.net/screenshots/000/000/088/large.png</screenshot>
+<screenshot>none</screenshot>
 
 <preinstall>
 
