@@ -5,11 +5,11 @@
 Media Center
 </category>
 
-<name>  
+<name>
 Plex
 </name>
 
-<description>  
+<description>
 Plex Mediaserver (includes web client)(requires reboot after install)
 </description>
 
@@ -22,7 +22,7 @@ all
 <preinstall>
 apt-get install apt-transport-https
 curl https://downloads.plex.tv/plex-keys/PlexSign.key | apt-key add -
-echo "deb https://downloads.plex.tv/repo/deb ./public main">/etc/apt/sources.list.d/plex.list
+echo "deb https://downloads.plex.tv/repo/deb public main">/etc/apt/sources.list.d/mxpitemp.list
 apt-get update
 </preinstall>
 
@@ -32,17 +32,14 @@ plexmediaserver
 
 
 <postinstall>
-rm -f /etc/apt/sources.list.d/plex.list
-cp /usr/share/mx-packageinstaller-pkglist/plex_stuff/default/plexmediaserver /etc/default/plexmediaserver
-chown -R plex:plex /var/lib/plexmediaserver/
-cp /usr/share/mx-packageinstaller-pkglist/plex_stuff/init/plexserver /etc/init.d/plexserver
-chmod a+x /etc/init.d/plexserver
-ln -fs /etc/init.d/plexserver /etc/init.d/plexmediaserver
-update-rc.d plexserver defaults
+if [ -x /usr/sbin/start_pms ]; then
+apt-get install plex-sysvinit-compat
+fi
 </postinstall>
 
 
 <uninstall_package_names>
 plexmediaserver
+plex-sysvinit-compat
 </uninstall_package_names>
 </app>
